/* eslint-disable */
// 该文件由 OneAPI 自动生成，请勿手动修改！
import { request } from '@umijs/max';

export async function shopTree(
  params,
  options,
) {
  return request('/admin/shop/tree', {
    method: 'GET',
    params: {
      ...params,
    },
    ...(options || {}),
  });
}


export async function shopItems(
  params,
  options,
) {
  return request('/admin/shop/items', {
    method: 'GET',
    params: {
      ...params,
    },
    ...(options || {}),
  });
}

export async function shopTrade(
  body,
  options,
) {
  return request('/admin/shop/trade', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}


export async function shopTemp(
  body,
  options,
) {
  return request('/admin/shop/temp', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}

export async function shopMoney(
  body,
  options,
) {
  return request('/admin/shop/money', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}


export async function shopCreate(
  body,
  options,
) {
  return request('/admin/shop/create', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}

export async function shopLevel(
  body,
  options,
) {
  return request('/admin/shop/level', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}

export async function shopDelete(
  body,
  options,
) {
  return request('/admin/shop/delete', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}

export async function shopItem(
  params,
  options,
) {
  return request('/admin/shop/item', {
    method: 'GET',
    params: { ...params },
    ...(options || {}),
  });
}

export async function shopTeam(
  body,
  options,
) {
  return request('/admin/shop/team', {
    method: 'POST',
    data: body,
    ...(options || {}),
  });
}